/*
** EPITECH PROJECT, 2020
** Dep_Olivier
** File description:
** Game
*/

#include "Game.hpp"
#include "WindowCalc.hpp"

Game::Game(sf::RenderWindow *clonewin)
{
    SpaceLock   *elem = nullptr;

    this->_box = new ToolsBox();
    this->_objects = new ObjectsBox();
    this->_win = clonewin;
    this->_background = new Picture("assets/images/BACKGAME.png");
    this->_personnage = new Personnage();
    for (int i = 0; i != 4; i++) {
        elem = new SpaceLock(i);
        this->_list.push_back(elem);
    }
}

Game::~Game()
{
    delete(this->_box);
    delete(this->_win);
    delete(this->_background);
    for (int i = 0; i != 4; i++) {
        delete(this->_list.front());
    }

}

ToolsBox    *Game::getToolsBox() const
{
    return (this->_box);
}

sf::Event   Game::getEvent() const
{
    return (this->_evt);
}

int Game::closeWin(void)
{
    if (this->_evt.type == sf::Event::Closed) {
        this->_win->close();
        return (1);
    }
    return (0);
}

int Game::clickOnButton(Picture *pic, sf::Vector2f pos)
{
    sf::FloatRect   rect = pic->getSprite().getGlobalBounds();

    if (rect.contains(pos)) {
        for (SpaceLock *elem : this->_list) {
            if (elem->getFull() == false && this->getObjectsBox()->getChairBroken()->getInRepair() == false) {
                elem->setObjInBoxPic(pic);
                elem->setFull(true);
                this->getObjectsBox()->getChairBroken()->setInRepair(true);
                return (1);
            }
        }
    }
    return (0);
}

int Game::manageAllEvent()
{
    sf::Vector2f    pos{0, 0};

    while (this->_win->pollEvent(this->_evt)) {
        pos.x = this->_evt.mouseButton.x;
        pos.y = this->_evt.mouseButton.y;
        if (this->closeWin() == 1)
            return (1);
        clickOnButton(this->_objects->getChairBroken()->getPicture(), pos);
    }
    return (0);
}

Picture *Game::getPicture() const
{
    return (this->_background);
}

ObjectsBox  *Game::getObjectsBox() const
{
    return (this->_objects);
}

Personnage  *Game::getPersonnage() const
{
    return (this->_personnage);
}

SpaceLock   *Game::getSpaceLock(int id) const
{
    for (SpaceLock *x : this->_list) {
        if (x->getId() == id)
            return(x);
    }
    return (nullptr);
}

void    Game::checkRepairObject(SpaceLock *elem)
{
    clock_t myTime = clock();
    double  pass = 0;

    while (true) {
        pass = (clock() - myTime) / CLOCKS_PER_SEC;
        if (pass == this->getObjectsBox()->getChairBroken()->getInRepair()) {
            elem->setObjInBoxPic(this->getObjectsBox()->getChair()->getPicture());
            break;
        }
    }
}

void    Game::printPicinList()
{
    int i = 0;

    for (SpaceLock *x : this->_list) {
        if (x->getFull() == true) {
            x->getObjPic()->setPositionSprite(91, 18 + (15 * i));
            this->_win->draw(x->getObjPic()->getSprite());
            this->checkRepairObject(x);
        }
        i++;
    }
}