/*
** EPITECH PROJECT, 2019
** ObjectCollection.cpp
** File description:
** ObjectCollection implementation function
*/

#include "ObjectCollection.hpp"

ObjectCollection::ObjectCollection(void)
{

}

void    ObjectCollection::fill(void)
{
    try {
        // Fonts
        addFont(FONT_ERAS_BOLD);
        addFont(FONT_ERAS_DEMI);
        addFont(FONT_ERAS_LITE);
        addFont(FONT_ERAS_MEDI);
        // Game Logo
        addTexture(GAME_LOGO);

        // InGame textures
        addTexture(ITEM_TABLE);
        addTexture(ITEM_BOOKSHELF);
        addTexture(ITEM_SHELF);
        addTexture(ITEM_DESK);
        addTexture(ITEM_CHAIR);
        addTexture(ITEM_GLUE);
        addTexture(ITEM_SCREWDRIVER);
        addTexture(ITEM_HAMMER);
        addTexture(ICON_GEAR);
        addTexture(ICON_BUCKS);
        // ... more ingame textures

        // Button textures
        addTexture(MENU_OPTION_CL);
        addTexture(MENU_OPTION_SL);
        addTexture(MENU_OPTION_NL);
        addTexture(MENU_PLAY_CL);
        addTexture(MENU_PLAY_SL);
        addTexture(MENU_PLAY_NL);
        addTexture(MENU_QUIT_CL);
        addTexture(MENU_QUIT_SL);
        addTexture(MENU_QUIT_NL);

        // Background Textures
        addTexture(SCENE_MENUBACK2);

    } catch (const std::exception &e) {
        std::cout << e.what() << std::endl;
        throw (e);
    }
}

ObjectCollection::~ObjectCollection(void)
{
    std::list<FontItem *>::iterator      ft;
    std::list<TextureItem *>::iterator   tt;

    for (ft = _fontCollection.begin(); ft != _fontCollection.end(); ft++) {
        delete (*ft);
    }
    for (tt = _textureCollection.begin(); tt != _textureCollection.end(); tt++) {
        delete (*tt);
    }
}

bool    ObjectCollection::addFont(const std::string &fontName)
{
    std::list<FontItem *>::iterator   it;

    if (_fontCollection.empty()) {
        _fontCollection.push_back(new FontItem(fontName));
        return (true);
    }

    for (it = _fontCollection.begin(); it != _fontCollection.end(); it++) {
        if ((*it)->getId().compare(fontName) == 0) {
            return (false);
        }
        _fontCollection.push_back(new FontItem(fontName));
        return (true);
    }
    return (false);
}

bool    ObjectCollection::addTexture(const std::string &textureName)
{
    std::list<TextureItem *>::iterator   it;

    if (_textureCollection.empty()) {
        _textureCollection.push_back(new TextureItem(textureName));
        return (true);
    }

    for (it = _textureCollection.begin(); it != _textureCollection.end(); it++) {
        if ((*it)->getId().compare(textureName) == 0) {
            return (false);
        }
        _textureCollection.push_back(new TextureItem(textureName));
        return (true);
    }
    return (false);
}


FontItem    *ObjectCollection::getFont(const std::string &fontName)
{
    std::list<FontItem *>::iterator   it;

    for (it = _fontCollection.begin(); it != _fontCollection.end(); it++) {
        if ((*it)->getId().compare(fontName) == 0) {
            return *it;
        }
    }
    return (nullptr);
}

TextureItem    *ObjectCollection::getTexture(const std::string &textureName)
{
    std::list<TextureItem *>::iterator   it;

    for (it = _textureCollection.begin(); it != _textureCollection.end(); it++) {
        if ((*it)->getId().compare(textureName) == 0) {
            return *it;
        }
    }
    return (nullptr);
}
