/*
** EPITECH PROJECT, 2019
** SceneManager.cpp
** File description:
** SceneManager functions implementation
*/

#include "SceneManager.hpp"

SceneManager::SceneManager(sf::RenderWindow *win) : _window(win)
{
    _objCol.fill();
}

void    SceneManager::initBackground(const std::string &backgroundId)
{
    _background.init(_window);
    _background.setTexture(_objCol.getTexture(backgroundId));
}

void    SceneManager::drawAll(void)
{
    std::list<MenuButton *>::iterator   it;

    _window->draw(_background);
    for (it = _menuButtons.begin(); it != _menuButtons.end(); it++) {
        _window->draw(*(*it));
    }
}

SceneManager::~SceneManager(void)
{
    std::list<MenuButton *>::iterator      ft;

    for (ft = _menuButtons.begin(); ft != _menuButtons.end(); ft++) {
        delete (*ft);
    }
}

MenuButton  *SceneManager::getButton(const std::string &id)
{
    std::list<MenuButton *>::iterator   it;

    for (it = _menuButtons.begin(); it != _menuButtons.end(); it++) {
        if ((*it)->getId().compare(id) == 0) {
            return *it;
        }
    }
    return (nullptr);
}

void    SceneManager::createMenuButton(const std::string&id, uint x, uint y,
        const std::string &idleTexture, const std::string &hoverTexture,
        const std::string &clickedTexture)
{
    MenuButton  *button = new MenuButton(_window, x, y);

    button->setId(id);
    button->chargeTextures(_objCol.getTexture(idleTexture),
                           _objCol.getTexture(hoverTexture),
                           _objCol.getTexture(clickedTexture));
    _menuButtons.push_back(button);
}

int     SceneManager::pollEvents(sf::Event &e)
{
    while (_window->pollEvent(e)) {
        if (e.type == sf::Event::Closed) {
            return (CODE_QUIT);
        }
        return (_pollButtonEvents(e));
    }
    return (CODE_MENU);
}

void    SceneManager::_buttonMoveEvent(sf::Event &e)
{
    std::list<MenuButton *>::iterator it;

    for (it = _menuButtons.begin(); it != _menuButtons.end(); it++) {
        if ((*it)->isHovered(e)) {
            (*it)->setHoverTexture();
        } else {
            (*it)->setIdleTexture();
        }
    }
}

int     SceneManager::_buttonClickEvent(sf::Event &e)
{
    std::list<MenuButton *>::iterator it;

    for (it = _menuButtons.begin(); it != _menuButtons.end(); it++) {
        if ((*it)->clickedInside(e)) {
            (*it)->setClickedTexture();
            return (_buttonFunctions.at((*it)->getId()));
        }
    }
    return (CODE_MENU);
}


int     SceneManager::_pollButtonEvents(sf::Event &e)
{
    switch (e.type)
    {
        case sf::Event::MouseButtonPressed:
            return (_buttonClickEvent(e));
            break;
        case sf::Event::MouseMoved:
            _buttonMoveEvent(e);
            break;
        default:
            break;
    }
    return (CODE_MENU);
}

void    SceneManager::addButtonFunction(const std::string &buttonId, int code)
{
    _buttonFunctions[buttonId] = code;
}
